Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
src/srunx/callbacks.py | Callback | 7 | 2 | 0 | 71%
src/srunx/callbacks.py | SlackCallback | 5 | 2 | 0 | 60%
src/srunx/callbacks.py | (no class) | 17 | 0 | 0 | 100%
src/srunx/cli/main.py | (no class) | 314 | 132 | 2 | 58%
src/srunx/cli/workflow.py | (no class) | 50 | 50 | 2 | 0%
src/srunx/client.py | Slurm | 123 | 20 | 0 | 84%
src/srunx/client.py | (no class) | 30 | 0 | 0 | 100%
src/srunx/config.py | ResourceDefaults | 0 | 0 | 0 | 100%
src/srunx/config.py | EnvironmentDefaults | 0 | 0 | 0 | 100%
src/srunx/config.py | SrunxConfig | 0 | 0 | 0 | 100%
src/srunx/config.py | (no class) | 133 | 20 | 0 | 85%
src/srunx/exceptions.py | WorkflowError | 0 | 0 | 0 | 100%
src/srunx/exceptions.py | WorkflowValidationError | 0 | 0 | 0 | 100%
src/srunx/exceptions.py | WorkflowExecutionError | 0 | 0 | 0 | 100%
src/srunx/exceptions.py | (no class) | 3 | 0 | 0 | 100%
src/srunx/logging.py | (no class) | 26 | 17 | 0 | 35%
src/srunx/models.py | JobStatus | 0 | 0 | 0 | 100%
src/srunx/models.py | JobResource | 0 | 0 | 0 | 100%
src/srunx/models.py | JobEnvironment | 7 | 0 | 0 | 100%
src/srunx/models.py | BaseJob | 24 | 7 | 0 | 71%
src/srunx/models.py | Job | 0 | 0 | 0 | 100%
src/srunx/models.py | ShellJob | 0 | 0 | 0 | 100%
src/srunx/models.py | Workflow | 62 | 27 | 0 | 56%
src/srunx/models.py | (no class) | 140 | 7 | 0 | 95%
src/srunx/runner.py | WorkflowRunner | 113 | 6 | 0 | 95%
src/srunx/runner.py | (no class) | 28 | 0 | 0 | 100%
src/srunx/utils.py | (no class) | 31 | 0 | 0 | 100%
Total |  | 1113 | 290 | 4 | 74%

No items found using the specified filter.